@@ -239,14 +239,14 @@ tokens.corpus <- function(x,
         dots$remove_hyphens <- NULL
     }
     if ("remove_twitter" %in% names(dots)) {
-        .Deprecated(msg = "'remove_twitter' is deprecated; for FALSE, use 'what = \"word2\"' instead.")
+        .Deprecated(msg = "'remove_twitter' is deprecated; for FALSE, use 'what = \"word\"' instead.")
         if (dots$remove_twitter == FALSE && what == "word1") what <- "word"
         dots$remove_twitter <- NULL
     }
     check_dots(dots, c(names(formals(tokens))))
 
     # call the appropriate tokenizer function
-    if (verbose) catm("...starting tokenization\n")
+    if (verbose) catm(" ...starting tokenization\n")
     tokenizer_fn <- switch(what,
                            word = tokenize_word,
                            word1 = tokenize_word1,
@@ -265,15 +265,16 @@ tokens.corpus <- function(x,
     # split x into smaller blocks to reducre peak memory consumption
     x <- split(x, ceiling(seq_along(x) / 10000))
     for (i in seq_along(x)) {
-        if (verbose) catm("...tokenizing", i, "of", length(x), "blocks\n")
+        if (verbose) catm(" ...tokenizing", i, "of", length(x), "blocks\n")
         temp <- tokenizer_fn(x[[i]], split_hyphens = split_hyphens, verbose = verbose)
-        if (verbose) catm("...serializing tokens ")
+        if (verbose) catm(" ...serializing tokens, ")
         if (i == 1) {
             x[[i]] <- serialize_tokens(temp)
         } else {
             x[[i]] <- serialize_tokens(temp, attr(x[[i - 1]], "types"))
         }
-        if (verbose) catm(length(attr(x[[i]], "types")), "unique types\n")
+        if (verbose) catm(format(length(attr(x[[i]], "types")), big.mark = ",", trim = TRUE),
+                          "unique types\n")
     }
     
     result <- build_tokens(
@@ -338,7 +339,7 @@ tokens.tokens <-  function(x,
 
     # splits
     if (split_hyphens) {
-        if (verbose) catm("...splitting hyphens\n")
+        if (verbose) catm(" ...splitting hyphens\n")
         x <- tokens_split(x, "\\p{Pd}", valuetype = "regex", remove_separator = FALSE)
     }
     
@@ -352,7 +353,7 @@ tokens.tokens <-  function(x,
                                        remove_numbers = remove_numbers,
                                        remove_url = remove_url)
     if (length(removals$regex_to_remove) || remove_separators) {
-        if (verbose) catm("...removing", paste(removals$removing_msg, collapse = ", "), "\n")
+        if (verbose) catm(" ...removing", paste(removals$removing_msg, collapse = ", "), "\n")
         x <- tokens_remove(x, paste(removals$regex_to_remove, collapse = "|"),
                            valuetype = "regex",  padding = padding,
                            startpos = 1L, endpos = -1L)
@@ -362,9 +363,9 @@ tokens.tokens <-  function(x,
         docvars(x) <- NULL
 
     if (verbose) {
-        catm("...total elapsed: ",
+        catm(" ...complete, elapsed time: ",
              format((proc.time() - tokens_env$START_TIME)[3], digits = 3), "seconds.\n")
-        catm("Finished constructing tokens from ", format(length(x), big.mark = ","), " text",
+        catm("Finished constructing tokens from ", format(length(x), big.mark = ","), " document",
              if (length(x) > 1) "s", ".\n", sep = "")
     }
     return(x)
@@ -481,8 +482,8 @@ compile_removals_regex <- function(remove_separators = FALSE,
         removing_msg <- c(removing_msg, "symbols")
     }
     if (remove_numbers) {
-        # includes currency amounts and those containing , or . digit separators
-        regex_to_remove <- c(regex_to_remove, "^\\p{Sc}{0,1}([0-9]{1,3}([,.][0-9]{3})*([,.][0-9]+)?|[.,][0-9]+)\\p{Sc}{0,1}$")
+        # includes currency amounts and those containing , or . digit separators, and 100bn
+        regex_to_remove <- c(regex_to_remove, "^\\p{Sc}{0,1}\\p{N}+([.,]*\\p{N})*\\p{Sc}{0,1}$")
         removing_msg <- c(removing_msg, "numbers")
     }
     if (remove_url) {
