@@ -17,13 +17,14 @@
 #' @export
 #' @seealso tokens_lookup
 #' @examples
-#' toks1 <- tokens(data_corpus_irishbudget2010, remove_punct = TRUE)
+#' toks1 <- tokens(data_corpus_inaugural, remove_punct = TRUE)
 #'
 #' # lemmatization
-#' infle <- c("foci", "focus", "focused", "focuses", "focusing", "focussed", "focusses")
-#' lemma <- rep("focus", length(infle))
-#' toks2 <- tokens_replace(toks1, infle, lemma, valuetype = "fixed")
-#' kwic(toks2, "focus*")
+#' taxwords <- c("tax", "taxing", "taxed", "taxed", "taxation")
+#' lemma <- rep("TAX", length(taxwords))
+#' toks2 <- tokens_replace(toks1, taxwords, lemma, valuetype = "fixed")
+#' kwic(toks2, "TAX") %>% 
+#'     tail(10)
 #'
 #' # stemming
 #' type <- types(toks1)
@@ -32,9 +33,9 @@
 #' identical(toks3, tokens_wordstem(toks1, "porter"))
 #'
 #' # multi-multi substitution
-#' toks4 <- tokens_replace(toks1, phrase(c("Minister Deputy Lenihan")),
-#'                               phrase(c("Minister Deputy Conor Lenihan")))
-#' kwic(toks4, phrase(c("Minister Deputy Conor Lenihan")))
+#' toks4 <- tokens_replace(toks1, phrase(c("Supreme Court")),
+#'                         phrase(c("Supreme Court of the United States")))
+#' kwic(toks4, phrase(c("Supreme Court of the United States")))
 tokens_replace <- function(x, pattern, replacement, valuetype = "glob",
                            case_insensitive = TRUE, verbose = quanteda_options("verbose")) {
     UseMethod("tokens_replace")
@@ -58,7 +59,9 @@ tokens_replace.tokens <- function(x, pattern, replacement, valuetype = "glob",
     type <- types(x)
     if (valuetype == "fixed" && !is.list(pattern) && !is.list(replacement)) {
         type_new <- replace_type(type, pattern, replacement, case_insensitive)
-        if (!identical(type, type_new)) {
+        if (identical(type, type_new)) {
+            result <- x
+        } else {
             attr(x, "types") <- type_new
             result <- tokens_recompile(x)
         }
