@@ -1,57 +1,59 @@
 #' Select or remove tokens from a tokens object
-#' 
-#' These function select or discard tokens from a \link{tokens} objects.  For 
-#' convenience, the functions \code{tokens_remove} and \code{tokens_keep} 
-#' are defined as shortcuts for 
-#' \code{tokens_select(x, pattern, selection = "remove")} and \code{tokens_select(x, pattern, selection = "keep")}, 
-#' respectively.  The most common 
-#' usage for \code{tokens_remove} will be to eliminate stop words from a text or
-#' text-based object, while the most common use of \code{tokens_select} will be 
-#' to select tokens with only positive pattern matches from a list of regular 
+#'
+#' These function select or discard tokens from a [tokens] objects.  For
+#' convenience, the functions `tokens_remove` and `tokens_keep` are defined as
+#' shortcuts for `tokens_select(x, pattern, selection = "remove")` and
+#' `tokens_select(x, pattern, selection = "keep")`, respectively.  The most
+#' common usage for `tokens_remove` will be to eliminate stop words from a text
+#' or text-based object, while the most common use of `tokens_select` will be to
+#' select tokens with only positive pattern matches from a list of regular
 #' expressions, including a dictionary.
-#' @param x \link{tokens} object whose token elements will be removed or kept
+#' @param x [tokens] object whose token elements will be removed or kept
 #' @inheritParams pattern
-#' @param selection whether to \code{"keep"} or \code{"remove"} the tokens 
-#'   matching \code{pattern}
+#' @param selection whether to `"keep"` or `"remove"` the tokens matching
+#'   `pattern`
 #' @inheritParams valuetype
-#' @param case_insensitive ignore case when matching, if \code{TRUE}
-#' @param verbose if \code{TRUE} print messages about how many tokens were 
-#'   selected or removed
-#' @param padding if \code{TRUE}, leave an empty string where the removed tokens
+#' @param verbose if `TRUE` print messages about how many tokens were selected
+#'   or removed
+#' @param padding if `TRUE`, leave an empty string where the removed tokens
 #'   previously existed.  This is useful if a positional match is needed between
-#'   the pre- and post-selected tokens, for instance if a window of adjacency 
+#'   the pre- and post-selected tokens, for instance if a window of adjacency
 #'   needs to be computed.
 #' @param window integer of length 1 or 2; the size of the window of tokens
-#'   adjacent to \code{pattern} that will be selected. The window is symmetric
+#'   adjacent to `pattern` that will be selected. The window is symmetric
 #'   unless a vector of two elements is supplied, in which case the first
-#'   element will be the token length of the window before \code{pattern}, and
-#'   the second will be the token length of the window after \code{pattern}.
-#'   The default is \code{0}, meaning that only the pattern matched token(s) are
+#'   element will be the token length of the window before `pattern`, and
+#'   the second will be the token length of the window after `pattern`.
+#'   The default is `0`, meaning that only the pattern matched token(s) are
 #'   selected, with no adjacent terms.
 #'
 #'   Terms from overlapping windows are never double-counted, but simply
-#'   returned in the pattern match. This is because \code{tokens_select} never
-#'   redefines the document units; for this, see \code{\link{kwic}}.
+#'   returned in the pattern match. This is because `tokens_select` never
+#'   redefines the document units; for this, see [kwic()].
+#' @param startpos,endpos integer; position of tokens in documents where pattern
+#'   matching starts and ends, where 1 is the first token in a document.  For
+#'   negative indexes, counting starts at the ending token of the document, so
+#'   that -1 denotes the last token in the document, -2 the second to last, etc.
 #' @param min_nchar,max_nchar optional numerics specifying the minimum and
 #'   maximum length in characters for tokens to be removed or kept; defaults are
-#'   \code{NULL} for no limits.  These are applied after (and hence, in addition
+#'   `NULL` for no limits.  These are applied after (and hence, in addition
 #'   to) any selection based on pattern matches.
-#' @return a \link{tokens} object with tokens selected or removed based on their
-#'   match to \code{pattern}
+#' @return a [tokens] object with tokens selected or removed based on their
+#'   match to `pattern`
 #' @export
-#' @examples 
+#' @examples
 #' ## tokens_select with simple examples
-#' toks <- tokens(c("This is a sentence.", "This is a second sentence."), 
+#' toks <- tokens(c("This is a sentence.", "This is a second sentence."),
 #'                  remove_punct = TRUE)
 #' tokens_select(toks, c("is", "a", "this"), selection = "keep", padding = FALSE)
 #' tokens_select(toks, c("is", "a", "this"), selection = "keep", padding = TRUE)
 #' tokens_select(toks, c("is", "a", "this"), selection = "remove", padding = FALSE)
 #' tokens_select(toks, c("is", "a", "this"), selection = "remove", padding = TRUE)
-#' 
+#'
 #' # how case_insensitive works
 #' tokens_select(toks, c("is", "a", "this"), selection = "remove", case_insensitive = TRUE)
 #' tokens_select(toks, c("is", "a", "this"), selection = "remove", case_insensitive = FALSE)
-#' 
+#'
 #' # use window
 #' tokens_select(toks, "second", selection = "keep", window = 1)
 #' tokens_select(toks, "second", selection = "remove", window = 1)
@@ -60,6 +62,7 @@ tokens_select <- function(x, pattern, selection = c("keep", "remove"),
                           valuetype = c("glob", "regex", "fixed"),
                           case_insensitive = TRUE, padding = FALSE, window = 0,
                           min_nchar = NULL, max_nchar = NULL,
+                          startpos = 1L, endpos = -1L,
                           verbose = quanteda_options("verbose")) {
     UseMethod("tokens_select")
 }
@@ -70,6 +73,7 @@ tokens_select.default <- function(x, pattern = NULL,
                                   valuetype = c("glob", "regex", "fixed"),
                                   case_insensitive = TRUE, padding = FALSE, window = 0,
                                   min_nchar = NULL, max_nchar = NULL,
+                                  startpos = 1L, endpos = -1L,
                                   verbose = quanteda_options("verbose")) {
     stop(friendly_class_undefined_message(class(x), "tokens_select"))
 }
@@ -91,29 +95,39 @@ tokens_select.default <- function(x, pattern = NULL,
 #' tokens_select(toks, feats, selection = "remove", padding = TRUE)
 #' tokens_select(toks, feats, selection = "remove", case_insensitive = FALSE)
 #' tokens_select(toks, feats, selection = "remove", padding = TRUE, case_insensitive = FALSE)
-#' 
-#' # With longer texts
+#'
+#' # with longer texts
 #' toks2 <- tokens(data_corpus_inaugural)
 #' tokens_select(toks2, stopwords("english"), "remove")
 #' tokens_select(toks2, stopwords("english"), "keep")
 #' tokens_select(toks2, stopwords("english"), "remove", padding = TRUE)
 #' tokens_select(toks2, stopwords("english"), "keep", padding = TRUE)
-#' 
-#' # With multiple words
+#'
+#' # with multiple words
 #' tokens_select(toks2, list(c("President", "*")), "keep")
 #' tokens_select(toks2, "President *", "keep") # simplified form
 #' tokens_select(toks2, list(c("*", "crisis")), "keep")
 #' tokens_select(toks2, "* crisis", "keep") # simplified form
-#' 
-#' # With minimun length
+#'
+#' # with minimum length
 #' tokens_select(toks2, min_nchar = 2, "keep") # simplified form
+#'
+#' # with starting adn ending positions
+#' tokens_select(toks, "*", startpos = 3)  # exclude first two tokens
+#' tokens_select(toks, "*", endpos = 3)    # include only first 3 tokens
+#' tokens_select(toks, "*", startpos = -3) # include only last 2 tokens
+#'
+#' # combining positional selection with pattern matching
+#' tokens_select(toks, "t*", endpos = 3)
 tokens_select.tokens <- function(x, pattern = NULL,
                                  selection = c("keep", "remove"),
                                  valuetype = c("glob", "regex", "fixed"),
                                  case_insensitive = TRUE, padding = FALSE, window = 0,
                                  min_nchar = NULL, max_nchar = NULL,
+                                 startpos = 1L, endpos = -1L,
                                  verbose = quanteda_options("verbose")) {
 
+    x <- as.tokens(x)
     selection <- match.arg(selection)
     valuetype <- match.arg(valuetype)
     attrs <- attributes(x)
@@ -127,7 +141,8 @@ tokens_select.tokens <- function(x, pattern = NULL,
             ids <- list()
         }
     } else {
-        ids <- pattern2list(pattern, type, valuetype, case_insensitive, attr(x, "concatenator"))
+        ids <- pattern2list(pattern, type, valuetype, case_insensitive,
+                            field_object(attrs, "concatenator"))
     }
 
     # selection by nchar
@@ -158,18 +173,17 @@ tokens_select.tokens <- function(x, pattern = NULL,
     if (length(window) > 2) stop("window must be a integer vector of length 1 or 2")
     if (length(window) == 1) window <- rep(window, 2)
     if (selection == "keep") {
-        x <- qatd_cpp_tokens_select(x, type, ids, 1, padding, window[1], window[2])
+        result <- qatd_cpp_tokens_select(x, type, ids, 1, padding, window[1], window[2], startpos, endpos)
     } else {
-        x <- qatd_cpp_tokens_select(x, type, ids, 2, padding, window[1], window[2])
+        result <- qatd_cpp_tokens_select(x, type, ids, 2, padding, window[1], window[2], startpos, endpos)
     }
-    attributes(x, FALSE) <- attrs
-    return(x)
+    rebuild_tokens(result, attrs)
 }
 
 #' @rdname tokens_select
-#' @param ... additional arguments passed by \code{tokens_remove} and
-#'   \code{tokens_keep} to \code{tokens_select}. Cannot include
-#'   \code{selection}.
+#' @param ... additional arguments passed by `tokens_remove` and
+#'   `tokens_keep` to `tokens_select`. Cannot include
+#'   `selection`.
 #' @export
 #' @examples
 #' # tokens_remove example: remove stopwords
@@ -178,7 +192,7 @@ tokens_select.tokens <- function(x, pattern = NULL,
 #'          wash2 <- "When the occasion proper for it shall arrive, I shall endeavor to express
 #'                    the high sense I entertain of this distinguished honor.")
 #' tokens_remove(tokens(txt, remove_punct = TRUE), stopwords("english"))
-#' 
+#'
 tokens_remove <- function(x, ...) {
     if ("selection" %in% names(list(...))) {
         stop("tokens_remove cannot include selection argument")
@@ -188,7 +202,7 @@ tokens_remove <- function(x, ...) {
 
 #' @rdname tokens_select
 #' @export
-#' @examples 
+#' @examples
 #' # token_keep example: keep two-letter words
 #' tokens_keep(tokens(txt, remove_punct = TRUE), "??")
 tokens_keep <- function(x, ...) {
