@@ -1,7 +1,14 @@
-#' @importFrom magrittr %>%
+#' Pipe operator
+#'
+#' See \code{magrittr::\link[magrittr:pipe]{\%>\%}} for details.
+#'
+#' @name %>%
+#' @rdname pipe
+#' @keywords internal
 #' @export
-magrittr::`%>%`
-
+#' @importFrom magrittr %>%
+#' @usage lhs \%>\% rhs
+NULL
 
 # rdname catm
 # messages() with some of the same syntax as cat(): takes a sep argument and
@@ -10,7 +17,6 @@ catm <- function(..., sep = " ", appendLF = FALSE) {
     message(paste(..., sep = sep), appendLF = appendLF)
 }
 
-
 # used in displaying verbose messages for tokens_select and dfm_select
 message_select <- function(selection, nfeats, ndocs, nfeatspad = 0, ndocspad = 0) {
     catm(if (selection == "keep") "kept" else "removed", " ",
@@ -22,7 +28,7 @@ message_select <- function(selection, nfeats, ndocs, nfeatspad = 0, ndocspad = 0
              " document", if (ndocs != 1L) "s" else "",
              sep = "")
     }
-    if ( (nfeatspad + ndocspad) > 0) {
+    if ((nfeatspad + ndocspad) > 0) {
         catm(", padded ", sep = "")
     }
     if (nfeatspad > 0) {
@@ -39,7 +45,6 @@ message_select <- function(selection, nfeats, ndocs, nfeatspad = 0, ndocspad = 0
     catm("", appendLF = TRUE)
 }
 
-
 ##
 ## reassign the slots to an S4 dfm-like object
 ## necessary when some operation from the Matrix class obliterates them
@@ -55,10 +60,9 @@ message_select <- function(selection, nfeats, ndocs, nfeatspad = 0, ndocspad = 0
 #     x_new
 # }
 
-
 #' Function extending base::attributes()
 #' @param x an object
-#' @param overwrite if \code{TRUE}, overwrite old attributes
+#' @param overwrite if `TRUE`, overwrite old attributes
 #' @param value new attributes
 #' @keywords internal
 "attributes<-" <- function(x, overwrite = TRUE, value) {
@@ -76,20 +80,20 @@ message_select <- function(selection, nfeats, ndocs, nfeatspad = 0, ndocspad = 0
 #' @param exceptions slots to ignore
 #' @param value a list of attributes extracted by attributes()
 #' @keywords internal
-"slots<-" <- function(x, exceptions = c("Dim", "Dimnames", "i", "p", "x", "factors"), value) {
-    slots <- methods::getSlots(class(x)[1])
-    for (sname in names(value)) {
-        if (!sname %in% names(slots) || sname %in% exceptions) next
-        if (!identical(typeof(value[[sname]]), slots[[sname]])) next
-        methods::slot(x, sname) <- value[[sname]]
-    }
-    return(x)
-}
+# "slots<-" <- function(x, exceptions = c("Dim", "Dimnames", "i", "p", "x", "factors"), value) {
+#     slot <- methods::getSlots(head(class(x)))
+#     for (name in names(value)) {
+#         if (!name %in% names(slot) || name %in% exceptions) next
+#         if (!identical(class(value[[name]]), unname(slot[name]))) next
+#         methods::slot(x, name) <- value[[name]]
+#     }
+#     return(x)
+# }
 
 #' Utility function to create a object with new set of attributes
 #' @param x an underlying R object of a new object
 #' @param attrs attributes of a new object
-#' @param overwrite_attributes overwrite attributes of the input object, if \code{TRUE}
+#' @param overwrite_attributes overwrite attributes of the input object, if `TRUE`
 #' @keywords internal
 create <- function(x, what, attrs = NULL, overwrite_attributes = FALSE, ...) {
     if (what == "tokens") {
@@ -102,28 +106,26 @@ create <- function(x, what, attrs = NULL, overwrite_attributes = FALSE, ...) {
     return(x)
 }
 
-
-#' Convert various input as pattern to a vector used in tokens_select, 
+#' Convert various input as pattern to a vector used in tokens_select,
 #' tokens_compound and kwic.
 #' @inheritParams pattern
 #' @inheritParams valuetype
-#' @param case_insensitive ignore the case of dictionary values if \code{TRUE}
 #' @param concatenator concatenator that join multi-word expression in tokens object
 #' @param levels only used when pattern is a dictionary
-#' @param remove_unigram ignore single-word patterns if \code{TRUE}
-#' @seealso \code{\link{pattern2id}}
+#' @param remove_unigram ignore single-word patterns if `TRUE`
+#' @seealso [pattern2id()]
 #' @keywords internal
-pattern2list <- function(pattern, types, valuetype, case_insensitive,
+pattern2list <- function(x, types, valuetype, case_insensitive,
                          concatenator = "_", levels = 1, remove_unigram = FALSE,
                          keep_nomatch = FALSE) {
 
-    if (is.dfm(pattern))
+    if (is.dfm(x))
         stop("dfm cannot be used as pattern")
 
-    if (is.collocations(pattern)) {
-        if (nrow(pattern) == 0) return(list())
-        temp <- stri_split_charclass(pattern$collocation, "\\p{Z}")
-        names(temp) <- pattern$collocation
+    if (is.collocations(x)) {
+        if (nrow(x) == 0) return(list())
+        temp <- stri_split_charclass(x$collocation, "\\p{Z}")
+        names(temp) <- x$collocation
         if (case_insensitive) {
             result <- pattern2id(temp, types, valuetype = "fixed", TRUE)
         } else {
@@ -132,65 +134,54 @@ pattern2list <- function(pattern, types, valuetype, case_insensitive,
         }
         attr(result, "pattern") <- match(names(result), names(temp))
     } else {
-        if (length(pattern) == 0) return(list())
-        if (is.dictionary(pattern)) {
-            temp <- flatten_dictionary(pattern, levels)
+        if (length(x) == 0) return(list())
+        if (is.dictionary(x)) {
+            x <- as.dictionary(x)
+            temp <- flatten_dictionary(x, levels)
             key <- names(temp)
-            temp <- split_values(temp, pattern@concatenator, concatenator)
-        } else if (is.list(pattern)) {
-            temp <- pattern
-            names(temp) <- stri_c_list(pattern, " ")
+            temp <- split_values(temp, " ", concatenator)
+        } else if (is.list(x)) {
+            temp <- x
+            names(temp) <- stri_c_list(x, " ")
         } else {
-            temp <- as.list(pattern)
-            names(temp) <- pattern
+            temp <- as.list(x)
+            names(temp) <- x
         }
         if (remove_unigram)
             temp <- temp[lengths(temp) > 1] # drop single-word patterns
         result <- pattern2id(temp, types, valuetype, case_insensitive, keep_nomatch)
         attr(result, "pattern") <- match(names(result), names(temp))
-        if (is.dictionary(pattern))
+        if (is.dictionary(x))
             attr(result, "key") <- key
     }
     return(result)
 }
 
-
-#' Internal function for \code{select_types()} to check if a string is a regular expression
+#' Internal function for `select_types()` to check if a string is a regular expression
 #' @param x a character string to be tested
 #' @keywords internal
-is_regex <- function(x){
+is_regex <- function(x) {
     any(stri_detect_fixed(x, c(".", "(", ")", "^", "{", "}", "+", "$", "*", "?", "[", "]", "\\")))
 }
 
-#' Internal function for \code{select_types()} to escape regular expressions 
-#' 
-#' This function escapes glob patterns before \code{utils:glob2rx()}, therefore * and ?
+#' Internal function for `select_types()` to escape regular expressions
+#'
+#' This function escapes glob patterns before `utils:glob2rx()`, therefore * and ?
 #' are unescaped.
 #' @param x character vector to be escaped
 #' @keywords internal
-escape_regex <- function(x){
+escape_regex <- function(x) {
     stri_replace_all_regex(x, "([.()^\\{\\}+$\\[\\]\\\\])", "\\\\$1") # allow glob
 }
 
-# function to check dots arguments against a list of permissible arguments
-check_dots <-  function(dots, permissible_args = NULL) {
-    if (length(dots) == 0) return()
-    args <- names(dots)
-    impermissible_args <-  setdiff(args, permissible_args)
-    if (length(impermissible_args))
-        warning("Argument", if (length(impermissible_args) > 1) "s " else " ",
-                paste(impermissible_args, collapse = ", "), " not used.",
-                noBreaks. = TRUE, call. = FALSE)
-}
-
 #' Print friendly object class not defined message
-#' 
-#' Checks valid methods and issues a friendlier error message in case the method is 
+#'
+#' Checks valid methods and issues a friendlier error message in case the method is
 #' undefined for the supplied object type.
 #' @param object_class character describing the object class
 #' @param function_name character which is the function name
 #' @keywords internal
-#' @examples 
+#' @examples
 #' # as.tokens.default <- function(x, concatenator = "", ...) {
 #' #     stop(quanteda:::friendly_class_undefined_message(class(x), "as.tokens"))
 #' # }
@@ -206,7 +197,7 @@ friendly_class_undefined_message <- function(object_class, function_name) {
 }
 
 #' Check if font is available on the system
-#' 
+#'
 #' This function checks if custom font is available to \pkg{ggplot} and
 #' \pkg{graphics} APIs.
 #' @param font name of a font to be checked if available on the system.
@@ -236,14 +227,25 @@ check_font <- function(font) {
 unused_dots <- function(...) {
     arg <- names(list(...))
     if (length(arg) == 1) {
-        warning(arg[1], " argument is not used in ",
-                sys.call(2)[1], "()", call. = FALSE)
+        warning(arg[1], " argument is not used.", call. = FALSE)
     } else if (length(arg) > 1) {
-        warning(paste0(arg, collapse = ", "), " arguments are not used in ",
-                sys.call(2)[1], "()", call. = FALSE)
+        warning(paste0(arg, collapse = ", "), " arguments are not used.", call. = FALSE)
     }
 }
 
+# function to check dots arguments against a list of permissible arguments
+# needed for tokens.R only
+# because (...) evaluated in parent fn is different from being passed through
+check_dots <-  function(dots, permissible_args = NULL) {
+    if (length(dots) == 0) return()
+    args <- names(dots)
+    arg <-  setdiff(args, permissible_args)
+    if (length(arg) == 1) {
+        warning(arg[1], " argument is not used.", call. = FALSE)
+    } else if (length(arg) > 1) {
+        warning(paste0(arg, collapse = ", "), " arguments are not used.", call. = FALSE)
+    }
+}
 
 #' Return an error message
 #' @param key type of error message
@@ -251,28 +253,32 @@ unused_dots <- function(...) {
 message_error <- function(key = NULL) {
     msg <- c("dfm_empty" = "dfm must have at least one non-zero value",
              "fcm_empty" = "fcm must have at least one non-zero value",
-             "docvar_mismatch" = "data.frame must have the same number of rows as documents",
+             "fcm_context" = "fcm must be created with a document context",
+             "matrix_mismatch" = "matrix must have the same rownames and colnames",
+             "docnames_mismatch" = "docnames must the the same length as x",
+             "docvars_mismatch" = "data.frame must have the same number of rows as documents",
+             "docvars_invalid" = "document variables cannot begin with the underscore",
              "docvar_nofield" = "you must supply field name(s)",
              "docvar_nocolname" = "data.frame must have column names")
     if (is.null(key) || !key %in% names(msg)) {
         return("")
     }
     return(unname(msg[key]))
-} 
+}
 
 #' Sample a vector by a group
-#' 
+#'
 #' Return a sample from a vector within a grouping variable.
 #' @param x any vector
 #' @param size the number of items to sample within each group, as a positive
 #'   number or a vector of numbers equal in length to the number of groups. If
-#'   \code{NULL}, the sampling is stratified by group in the original group
+#'   `NULL`, the sampling is stratified by group in the original group
 #'   sizes.
-#' @param group a grouping vector equal in length to \code{length(x)}
+#' @param group a grouping vector equal in length to `length(x)`
 #' @param replace logical; should sampling be with replacement?
-#' @return \code{x} resampled within groups
+#' @return `x` resampled within groups
 #' @keywords internal
-#' @examples 
+#' @examples
 #' set.seed(100)
 #' grvec <- c(rep("a", 3), rep("b", 4), rep("c", 3))
 #' quanteda:::sample_bygroup(1:10, group = grvec, replace = FALSE)
@@ -283,7 +289,7 @@ sample_bygroup <- function(x, group, size = NULL, replace = FALSE) {
     if (length(x) != length(group))
         stop("group not equal in length of x")
     x <- split(x, group)
-    if (is.null(size)) 
+    if (is.null(size))
         size <- lengths(x)
     if (length(size) > 1 && length(size) != length(x))
         stop("size not equal in length to the number of groups")
@@ -291,4 +297,51 @@ sample_bygroup <- function(x, group, size = NULL, replace = FALSE) {
                  x[sample.int(length(x), size = size, replace = replace)]
               }, x, size, replace, SIMPLIFY = FALSE)
     unlist(result, use.names = FALSE)
+
+}
+
+#' Get the package version that created an object
+#'
+#' Return the the \pkg{quanteda} package version in which a [dfm],
+#' [tokens], or [corpus] object was created.
+#' @return A three-element integer vector of class "package_version". For
+#'   versions of the package < 1.5 for which no version was recorded in the
+#'   object, `c(1, 4, 0)` is returned.
+#' @keywords internal utils
+get_object_version <- function(x) {
+    if (is_pre2(x)) {
+        as.package_version("1.4.0")
+    } else {
+        meta(x, field = "package-version", type = "system")
+    }
+}
+
+#' @rdname get_object_version
+#' @return `ispre2()` returns `TRUE` if the object was created before
+#' \pkg{quanteda} version 2, or `FALSE` otherwise
+is_pre2 <- function(x) {
+    is.null(attributes(x)[["meta"]][["object"]])
+}
+
+# internal function to rbind data.frames that have different columns
+rbind_fill <- function(x, y) {
+    name1 <- names(x)
+    name2 <- names(y)
+    if (!identical(name1, name2)) {
+        name <- union(name1, name2)
+        name1_missing <- setdiff(name, name1)
+        if (length(name1_missing)) {
+            fill1 <- rep(list(rep(NA, nrow(x))), length(name1_missing))
+            names(fill1) <- name1_missing
+            x <- cbind(x, fill1)
+        }
+
+        name2_missing <- setdiff(name, name2)
+        if (length(name2_missing)) {
+            fill2 <- rep(list(rep(NA, nrow(y))), length(name2_missing))
+            names(fill2) <- name2_missing
+            y <- cbind(y, fill2)
+        }
+    }
+    return(rbind(x, y))
 }
