@@ -64,28 +64,30 @@ test_that("read a dictionary with NA as a key", {
 
 test_that("as.yaml is working", {
     expect_equivalent(quanteda::as.yaml(marydict),
-                      'A CATEGORY:\n  - more\n  - lamb\n  - little\nANOTHER CATEGORY:\n  - had\n  - mary\n')
+                      "A CATEGORY:\n  - more\n  - lamb\n  - little\nANOTHER CATEGORY:\n  - had\n  - mary\n")
 })
 
 test_that("dictionary works with different encoding", {
   skip_on_os("windows")
   suppressWarnings({
-    
+
     # works without specifying encoding
     expect_equivalent(dictionary(file = "../data/dictionaries/iso-8859-1.cat", tolower = FALSE),
-                      dictionary(list('LATIN' = c('B', 'C', 'D'), 'NON-LATIN' = c('Bh', 'Ch', 'Dh')), tolower = FALSE))
+                      dictionary(list("LATIN" = c("B", "C", "D"), "NON-LATIN" = c("Bh", "Ch", "Dh")), tolower = FALSE))
     expect_equivalent(dictionary(file = "../data/dictionaries/windows-1252.cat", tolower = FALSE),
-                      dictionary(list('LATIN' = c('S', 'Z', 'Y'), 'NON-LATIN' = c('Š', 'Ž', 'Ÿ')), tolower = FALSE))
-    
+                      dictionary(list("LATIN" = c("S", "Z", "Y"), "NON-LATIN" = c("Š", "Ž", "Ÿ")), tolower = FALSE))
+
     # works if encoding is specified
-    expect_equivalent(dictionary(file = "../data/dictionaries/iso-8859-2.cat", encoding = 'iso-8859-2', tolower = FALSE),
-                      dictionary(list('LATIN' = c('C', 'D', 'E'), 'NON-LATIN' = c('Č', 'Ď', 'Ě')), tolower = FALSE))
-    expect_equivalent(dictionary(file = "../data/dictionaries/iso-8859-14.cat", encoding = 'iso-8859-14', tolower = FALSE),
-                      dictionary(list('LATIN' = c('B', 'C', 'D'), 'NON-LATIN' = c('Ḃ', 'Ċ', 'Ḋ')), tolower = FALSE))
-    expect_equivalent(dictionary(file = "../data/dictionaries/shift-jis.cat", encoding = 'shift-jis', tolower = FALSE),
-                      dictionary(list('LATIN' = c('A', 'I', 'U'), 'NON-LATIN' = c('あ', 'い', 'う')), tolower = FALSE))
-    expect_equivalent(dictionary(file = "../data/dictionaries/euc-jp.cat", encoding = 'euc-jp', tolower = FALSE),
-                      dictionary(list('LATIN' = c('A', 'I', 'U'), 'NON-LATIN' = c('あ', 'い', 'う')), tolower = FALSE))
+    expect_equivalent(dictionary(file = "../data/dictionaries/iso-8859-2.cat", encoding = "iso-8859-2",
+                                 tolower = FALSE),
+                      dictionary(list("LATIN" = c("C", "D", "E"), "NON-LATIN" = c("Č", "Ď", "Ě")), tolower = FALSE))
+    expect_equivalent(dictionary(file = "../data/dictionaries/iso-8859-14.cat", encoding = "iso-8859-14",
+                                 tolower = FALSE),
+                      dictionary(list("LATIN" = c("B", "C", "D"), "NON-LATIN" = c("Ḃ", "Ċ", "Ḋ")), tolower = FALSE))
+    expect_equivalent(dictionary(file = "../data/dictionaries/shift-jis.cat", encoding = "shift-jis", tolower = FALSE),
+                      dictionary(list("LATIN" = c("A", "I", "U"), "NON-LATIN" = c("あ", "い", "う")), tolower = FALSE))
+    expect_equivalent(dictionary(file = "../data/dictionaries/euc-jp.cat", encoding = "euc-jp", tolower = FALSE),
+                      dictionary(list("LATIN" = c("A", "I", "U"), "NON-LATIN" = c("あ", "い", "う")), tolower = FALSE))
   })
 })
 
@@ -98,23 +100,23 @@ test_that("tolower is working", {
                              SUBKEY6 = list(SUBKEY8 = c("L"))))
     dict <- dictionary(list, tolower = FALSE)
     dict_lower <- dictionary(list, tolower = TRUE)
-    
+
     expect_equal(names(unlist(list)), names(unlist(dict)))
     expect_equal(names(unlist(dict_lower)), names(unlist(dict)))
-    expect_equal(unlist(list, use.names = FALSE), 
+    expect_equal(unlist(list, use.names = FALSE),
                  unlist(dict, use.names = FALSE))
-    expect_equal(stringi::stri_trans_tolower(unlist(list, use.names = FALSE)), 
+    expect_equal(stringi::stri_trans_tolower(unlist(list, use.names = FALSE)),
                  unlist(dict_lower, use.names = FALSE))
 })
 
 test_that("indexing for dictionary objects works", {
     testdict <- dictionary(file = "../data/dictionaries/laver-garry.cat")
     expect_true(is.dictionary(testdict[1:2]))
-    expect_equal(names(testdict[1]), 'CULTURE')
-    expect_equal(names(testdict[[1]][1]), 'CULTURE-HIGH')
-    expect_equal(names(testdict[2]), 'ECONOMY')
-    expect_equal(names(testdict[[2]][1]), '+STATE+')
-    
+    expect_equal(names(testdict[1]), "CULTURE")
+    expect_equal(names(testdict[[1]][1]), "CULTURE-HIGH")
+    expect_equal(names(testdict[2]), "ECONOMY")
+    expect_equal(names(testdict[[2]][1]), "+STATE+")
+
     expect_output(
         print(testdict),
         "Dictionary object with 9 primary key entries and 2 nested levels"
@@ -125,42 +127,74 @@ test_that("indexing for dictionary objects works", {
     )
 })
 
-test_that("indexing for dictionary keys works", {
+test_that("dictionary printing works", {
     dict <- dictionary(list(one = c("a", "b"), two = c("c", "d")))
     expect_true(is.dictionary(dict[1]))
-    expect_equal(
-        dict[1],
-        dictionary(list(one = c("a", "b")))
-    )
 
     expect_output(
         print(dict),
-        "Dictionary object with 2 key entries\\."
+        paste0(
+            "Dictionary object with 2 key entries.\n",
+            "- [one]:\n",
+            "  - a, b\n",
+            "- [two]:\n",
+            "  - c, d"
+        ),
+        fixed = TRUE
     )
     expect_output(
-        print(dict[1]),
-        "Dictionary object with 1 key entry\\."
+        print(dict, max_nkey = 1),
+        paste0(
+            "Dictionary object with 2 key entries.\n",
+            "- [one]:\n",
+            "  - a, b\n",
+            "[ reached max_nkey ... 1 more key ]"
+        ),
+        fixed = TRUE
     )
-    
-    testdict <- dictionary(file = "../data/dictionaries/issue-459.cat")
-    expect_identical(
-        testdict[["SOUTH"]],
-        testdict$SOUTH
+    expect_output(
+        print(dict, max_nkey = -1, max_nval = -1),
+        paste0(
+            "Dictionary object with 2 key entries.\n",
+            "- [one]:\n",
+            "  - a, b\n",
+            "- [two]:\n",
+            "  - c, d"
+        ),
+        fixed = TRUE
+    )
+    expect_output(
+        print(dict, max_nkey = 1, max_nval = 1),
+        paste0(
+            "Dictionary object with 2 key entries.\n",
+            "- [one]:\n",
+            "  - a [ ... and 1 more ]\n",
+            "[ reached max_nkey ... 1 more key ]"
+        ),
+        fixed = TRUE
+    )
+
+    expect_output(
+        print(dict, max_nkey = 1, max_nval = 1, show_summary = FALSE),
+        paste0(
+            "- [one]:\n",
+            "  - a [ ... and 1 more ]\n",
+            "[ reached max_nkey ... 1 more key ]"
+        ),
+        fixed = TRUE
     )
-    
-    
 })
 
 
 test_that("dictionary_depth works correctly", {
     dict1 <- dictionary(list(one = c("a", "b"), two = c("c", "d")))
     expect_equal(quanteda:::dictionary_depth(dict1), 1)
-    
-    dict2 <- dictionary(list(one = c("a", "b"), 
+
+    dict2 <- dictionary(list(one = c("a", "b"),
                         two = list(sub1 = c("c", "d"),
                                    sub2 = c("e", "f"))))
     expect_equal(quanteda:::dictionary_depth(dict2), 2)
-    
+
     expect_output(
         print(dict2),
         "Dictionary object with 2 primary key entries and 2 nested levels\\."
@@ -168,8 +202,8 @@ test_that("dictionary_depth works correctly", {
 })
 
 test_that("as.list is working", {
-    
-    lis <- list(top1 = c("a", "b"), top2 = c("c", "d"), 
+
+    lis <- list(top1 = c("a", "b"), top2 = c("c", "d"),
                 top3 = list(sub1 = c("e", "f"),
                             sub2 = c("f", "h")))
     dict <- dictionary(lis)
@@ -210,12 +244,12 @@ test_that("error if empty separator is given", {
 
 test_that("dictionary woks with the Yoshicoder format", {
     testdict <- dictionary(file = "../data/dictionaries/laver-garry.ykd")
-    expect_equal(names(testdict), 'Laver and Garry') 
-    expect_equal(names(testdict[['Laver and Garry']]), 
-                 c("State in Economy", "Institutions", "Values", "Law and Order", "Environment", 
+    expect_equal(names(testdict), "Laver and Garry")
+    expect_equal(names(testdict[["Laver and Garry"]]),
+                 c("State in Economy", "Institutions", "Values", "Law and Order", "Environment",
                    "Culture", "Groups", "Rural", "Urban"))
-    
-})    
+
+})
 
 
 test_that("dictionary constructor works with LIWC format w/doubled terms", {
@@ -237,7 +271,7 @@ test_that("dictionary constructor works with LIWC format zero padding", {
 test_that("dictionary constructor reports mssing cateogries in LIWC format", {
     expect_message(
         dictionary(file = "../data/dictionaries/mary_missingcat.dic"),
-        "note: ignoring undefined categories:" 
+        "note: ignoring undefined categories:"
     )
 })
 
@@ -282,17 +316,17 @@ test_that("dictionary constructor works with LIWC format w/extra codes", {
         dictionary(file = "../data/dictionaries/liwc_extracodes.dic"),
         "note: removing empty key: friend"
     )
-    
+
     dict <- dictionary(file = "../data/dictionaries/liwc_extracodes.dic")
     expect_equal(
-        length(dict), 
+        length(dict),
         10
     )
     expect_true(setequal(
-        names(dict), 
+        names(dict),
         c("verb", "past", "whatever", "family", "affect", "posemo", "cogmech", "tentat", "whatever2", "time")
     ))
-    
+
     # dict1 <- quanteda:::read_dict_liwc("../data/dictionaries/liwc_extracodes.dic")
     # dict2 <- quanteda:::list2dictionary(quanteda:::read_dict_liwc_old("../data/dictionaries/liwc_extracodes.dic"))
     # expect_equal(dict1[order(names(dict1))], dict2[order(names(dict2))])
@@ -343,7 +377,7 @@ test_that("dictionary constructor works with LIWC format w/extra codes and nesti
 test_that("dictionary works with yoshicoder, issue 819", {
     expect_equal(
         as.list(dictionary(file = "../data/dictionaries/issue-819.ykd")),
-        list('Dictionary' = list('pos' = list('A' = 'a word', 'B' = 'b word'))))
+        list("Dictionary" = list("pos" = list("A" = "a word", "B" = "b word"))))
 })
 
 test_that("dictionary constructor works on a dictionary", {
@@ -367,70 +401,71 @@ test_that("dictionary constructor works on a dictionary", {
 })
 
 test_that("combine method is working with dictionary objects", {
-    
-    dict1 <- dictionary(list(A = c('aa', 'aaa')))
-    dict2 <- dictionary(list(B = c('b', 'bb')))
-    dict3 <- dictionary(list(A = c('aaaa', 'aaaaa')))
+
+    dict1 <- dictionary(list(A = c("aa", "aaa")), separator = "+")
+    dict2 <- dictionary(list(B = c("b", "bb")), separator = "-")
+    dict3 <- dictionary(list(A = c("aaaa", "aaaaa")))
     expect_equal(c(dict1, dict2),
-                 dictionary(list(A = c('aa', 'aaa'), B = c('b', 'bb'))))
+                 dictionary(list(A = c("aa", "aaa"), B = c("b", "bb")), separator = "+"))
     expect_equal(c(dict1, dict2, dict3),
-                 dictionary(list(A = c('aa', 'aaa'), B = c('b', 'bb'), A = c('aaaa', 'aaaaa'))))
+                 dictionary(list(A = c("aa", "aaa"), B = c("b", "bb"), A = c("aaaa", "aaaaa")), 
+                            separator = "+"))
 })
 
 test_that("dictionary constructor clean values", {
-    
-    dict1 <- dictionary(list(A = c('aa  ', '  aaa  ')))
-    dict2 <- dictionary(list(B = c('b', 'bb', 'bb')))
-    
+
+    dict1 <- dictionary(list(A = c("aa  ", "  aaa  ")))
+    dict2 <- dictionary(list(B = c("b", "bb", "bb")))
+
     # trim whitespaces
     expect_equal(dict1,
-                 dictionary(list(A = c('aa', 'aaa'))))
-    
+                 dictionary(list(A = c("aa", "aaa"))))
+
     # remove duplicates
     expect_equal(dict2,
-                 dictionary(list(B = c('b', 'bb'))))
+                 dictionary(list(B = c("b", "bb"))))
 })
 
 test_that("dictionary merge values in duplicate keys", {
-    
-    dict <- dictionary(list(A = 'a', 
-                            A = 'aa', 
-                            A = 'aaa',
-                            B = list(BB = 'bb'),
-                            B = list(BB = 'bbb'),
-                            C = 'c'))
-    
+
+    dict <- dictionary(list(A = "a",
+                            A = "aa",
+                            A = "aaa",
+                            B = list(BB = "bb"),
+                            B = list(BB = "bbb"),
+                            C = "c"))
+
     expect_equal(dict,
-                 dictionary(list(A = c('a', 'aa', 'aaa'),
-                                 B = list(BB = c('bb', 'bbb')),
-                                 C = 'c')))
-    
+                 dictionary(list(A = c("a", "aa", "aaa"),
+                                 B = list(BB = c("bb", "bbb")),
+                                 C = "c")))
+
 })
 
 test_that("pattern2list() preserves the order of keys and values", {
-  
+
   type <- stopwords()
   dict1 <- dictionary(list(th = c("tho*", "the"), wh = "wh*", ng = "not *"))
   dict2 <- dictionary(list(ng = "not *", th = c("tho*", "the"), wh = "wh*"))
   dict3 <- dictionary(list(ng = "not *", wh = "wh* is", th = c("tho*", "the")))
   dict4 <- dictionary(list(ng = "not *", th = c("tho*", "the"), wh = "wh* is"))
-  
+
   ids1 <- quanteda:::pattern2list(dict1, type, "glob", FALSE)
   expect_identical(unique(names(ids1)), names(dict1))
-  
+
   ids2 <- quanteda:::pattern2list(dict2, type, "glob", FALSE)
   expect_identical(unique(names(ids2)), names(dict2))
-  
+
   ids3 <- quanteda:::pattern2list(dict3, type, "glob", FALSE)
   expect_identical(unique(names(ids3)), names(dict3))
-  
+
   ids4 <- quanteda:::pattern2list(dict4, type, "glob", FALSE)
   expect_identical(unique(names(ids4)), names(dict4))
 })
 
 
 test_that("split_values() handle concatenators correctly", {
-    
+
     expect_identical(
         quanteda:::split_values(list(A = "a_a", "b_b"), "_", " "),
         list(A = c("a", "a"), A = "a a", c("b", "b"), "b b")
@@ -447,5 +482,5 @@ test_that("split_values() handle concatenators correctly", {
         quanteda:::split_values(list(A = "a_a", "A_A"), " ", " "),
         list(A = "a_a", "A_A")
     )
-    
+
 })
