@@ -1,7 +1,7 @@
 context("test textplot_network.R")
 
 test_that("test textplot_network", {
-    skip_on_os("linux")
+    #skip_on_os("linux")
     txt <- "A D A C E A D F E B A C E D"
     testfcm <- fcm(txt, context = "window", window = 3, tri = FALSE)
     testdfm <- dfm(txt)
@@ -17,7 +17,7 @@ test_that("test textplot_network", {
 
 
 test_that("test textplot_network works with vectorlized argument", {
-    skip_on_os("linux")
+    #skip_on_os("linux")
     txt <- "A D A C E A D F E B A C E D"
     
     testfcm <- fcm(txt, context = "window", window = 3, tri = FALSE)
@@ -28,6 +28,7 @@ test_that("test textplot_network works with vectorlized argument", {
 })
 
 test_that("textplot_network error when fcm is too large", {
+    data(data_corpus_irishbudget2010, package = "quanteda.textmodels")
     testdfm <- dfm(data_corpus_irishbudget2010)
     expect_error(textplot_network(testdfm, min_freq = 1, offset = 0, omit_isolated = FALSE),
                  'fcm is too large for a network plot')
